# Quantum-accelerated supercomputing atomistic simulations for corrosion inhibition

This contains the quantum chemistry and quantum computing calculations for the "Quantum-Accelerated Supercomputing Atomistic Simulations for Corrosion Inhibition" publication. The arXiv preprint is available at https://arxiv.org/abs/2412.00951.

## Description
This dataset supports a systematic implementation of hybrid quantum-classical computational methods for investigating corrosion inhibition mechanisms on aluminum surfaces. The work presents an integrated workflow combining density functional theory (DFT) with quantum algorithms through an active space embedding scheme, specifically applied to studying 1,2,4-Triazole and 1,2,4-Triazole-3-thiol inhibitors on Al111 surfaces. The methodology employs the orb-d3-v2 machine learning potential for rapid geometry optimizations, followed by accurate DFT calculations using CP2K with PBE functional and Grimme's D3 dispersion corrections. Our implementation leverages the ADAPT-VQE algorithm with benchmarking against classical DFT calculations, achieving binding energies of -0.386 eV and -1.279 eV for 1,2,4-Triazole and 1,2,4-Triazole-3-thiol, respectively.

## Directory Structure

The calculations are organized for two inhibitor molecules:
1. Al_triazole_qiskit_adaptVQE (Using adaptive VQE approach)
2. Al_triazole_qiskit_onlyVQE (Using standard VQE approach)
3. Al_Triazole-3-thiol_qiskit_adaptVQE (Thiol variant with adaptive VQE)

Each molecule's calculations follow a systematic workflow with the following subdirectories:
- `0_classical_calculations/`: Initial classical DFT calculations
- `1_visualization/`: Molecular visualization data and scripts
- `2_supercell/`: Periodic boundary condition calculations
- `3_Al/`: Aluminum surface calculations
- `4_inhibitor/`: Inhibitor molecule calculations

## Detailed Directory Structure

Each molecule's directory contains the following structure:

### 0_classical_calculations/
- **0_Al_slab_*_generation/**: Initial structure generation
  - `*_generator.py`: Python script for structure generation
  - `*.xyz`: Generated molecular structures
  - `*.png`: Structure visualizations
- **1_geometry_optimization/**: Geometry optimization calculations
  - `use_orb.py`: Script using orb-d3-v2 ML potential
  - Input/output files for optimization
- **2_supercell/**: Periodic boundary calculations
  - `*.fcidump`: Electronic structure data
  - `*.wfn`: Wavefunction files
  - `*.inp`: CP2K input files
  - `quantum_calculation_results.json`: Quantum calculation outputs

### 1_visualization/
- `*.xyz`: Structure files
- `*.png`, `*.svg`: High-quality visualizations from different perspectives
  - Side view
  - Top view
  - Supercell visualizations

### 2_supercell/, 3_Al/, 4_inhibitor/
Each contains quantum chemistry calculations with:
- CP2K input files (`*.inp`)
- Quantum VQE calculation scripts (`client-vqe-ucc.py`)
- Results and logs (`quantum_calculation_results.json`, `*.log`)
- Wavefunction and electronic structure data

### Analysis Files
- `analysis.ipynb`: Jupyter notebooks containing data analysis and results
- `classical_analysis.ipynb`: Classical calculations analysis

## File Formats
- **Structural Data**: XYZ format (`.xyz`)
- **Quantum Chemistry**: FCIDUMP format (`.fcidump`)
- **Visualization**: Vector and bitmap formats (`.svg`, `.png`)
- **Results**: JSON and text formats (`.json`, `.log`)
- **Analysis**: Jupyter notebooks (`.ipynb`)

## Technical Details

### Quantum Chemistry Calculations (CP2K)
- Software Version: CP2K 2024.3
- DFT Settings:
  - Spin restricted Kohn-Sham (RKS)
  - PBE functional
  - Periodic boundary conditions
  - Electronic temperature: 1000K
  - Cutoff settings:
    - Density: 1.0E-10
    - Gradient: 1.0E-10
    - Tau: 1.0E-10

### Quantum Computing Simulations
- Framework: Qiskit
- VQE Implementations:
  - Standard VQE
  - Adaptive VQE (with dynamic operator pool)
- Output files:
  - `cp2k.log`: CP2K calculation results
  - `python_output.log`: VQE calculation results

## Running the Calculations

Each calculation directory contains a `run.sh` script that executes both CP2K and VQE calculations, example usage can be:
```bash
cd Al_triazole_qiskit_adaptVQE/2_supercell
nohup ./run.sh &
```

## Notes
- All calculations use restricted Kohn-Sham DFT
- The VQE calculations are performed after the DFT calculations complete
- Molecular geometries and electronic structure data are preserved in respective output files

## Data format
All data is stored in the following::
- Molecular structures: XYZ format (.xyz)
- Calculation inputs: input files (.inp)
- Results: CSV and JSON formats (.csv, .json)
- Visualization: Standard image formats (.png, .svg)

## Associated Publication
This dataset supports the following publication:
- Karim Elgammal, & Marc Maußner (2024). A Quantum Computing Approach to Simulating Corrosion Inhibition. *arXiv preprint* arXiv:2412.00951.
  - Preprint: https://arxiv.org/abs/2412.00951
  - Field: Condensed Matter > Materials Science